@@ -3,6 +3,7 @@ jsio('from net.protocols.rtjp import RTJPProtocol');
 
 exports.logging = logging
 
+
 exports.connect = function(url, cookieString) {
 	if (!url.match('/$')) {
 		url = url + '/';
@@ -196,6 +197,10 @@ HookBoxProtocol = Class([RTJPProtocol], function(supr) {
 			case 'ERROR':
 				this.onError(fArgs);
 				break;
+				
+			case 'SET_COOKIE':
+				document.cookie = fArgs.cookie;
+				break;
 		}
 	}
 	this.connectionLost = function() {
@@ -204,13 +209,12 @@ HookBoxProtocol = Class([RTJPProtocol], function(supr) {
 		this.onClose();
 	}
 
-	// TODO: we need another var besides this.connnected, as that becomes true
-	//       only after we get a CONNECTED frame. Maybe our transport is
-	//       connected, but we haven't gotten the frame yet. For now, no one
-	//       should be calling this anyway until they get an onclose.
-
-	this.reconnect = function() {
-		jsioConnect(this, this.url);
+	this.connectionFailed = function(transportName) {
+		logger.debug('connectionFailed', transportName)
+		if (transportName == 'websocket') {
+			logger.debug('retry with csp');
+			jsioConnect(this, 'csp', {url: this.url + 'csp'})
+		}
 	}
 	
 	this.disconnect = function() {
